==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingViewport.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingViewport

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 4748b761216cf334 javax_swing_JViewport
// @dep_class 38da19350e7e577 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport

// header file dependencies
// @dep_header javax_swing_JViewport

#include "javax/swing/JViewport.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$method$_init$dc55aec96131705b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JViewport$vmethods	javax_swing_JViewport;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport;
    _jc_javax_swing_JViewport$sub_refs	javax_swing_JViewport;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JViewport$sub_nonrefs	javax_swing_JViewport;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingViewport.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingViewport

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 4748b761216cf334 javax_swing_JViewport
// @dep_class 38da19350e7e577 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport

// header file dependencies
// @dep_header javax_swing_JViewport

#include "javax/swing/JViewport.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$method$_init$dc55aec96131705b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JViewport$vmethods	javax_swing_JViewport;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport;
    _jc_javax_swing_JViewport$sub_refs	javax_swing_JViewport;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JViewport$sub_nonrefs	javax_swing_JViewport;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingViewport_H_ */
